#!/bin/csh

# This file is processed by "make" to create file run by
# the MAST web service.

set dir = `pwd`
set jobid  = `basename $dir`

# get log file
set logfile = /opt/chipster/tools/meme_4.2.0/LOGS/mast-log

# get the background 
set bkg = /opt/chipster/tools/meme_4.2.0/etc/bkg.jpg
if -e $bkg cp $bkg .

#
# create an empty index file
#
cat > index.html << HERE
<html>
<head>
<title>MAST Output</title>
</head>
<body background="bkg.jpg">

<hr>
<h2>MAST Job $jobid</h2>
HERE

# Get start time for log
set t1 = `date -u '+%d/%m/%y %H:%M:%S'`

#
# get the motif file name and DB file name from first two arguments
#
set motifs = $1; shift
set db = $1; shift

# append the local database path unless DB is an uploaded database
#
if ($db != "uploaded_db") set db = /opt/chipster/tools/meme_4.2.0/db/fasta_databases/$db

#
# set up the background file and number of sequences in 
# the db file switches if those local files exist
#
set bfile = ''; set nseqs = ''
echo "$*" | grep -e '-dna' > /dev/null	# see if -dna given; no bfile if so
if (-e $db.bfile && $status) set bfile = "-bfile $db.bfile"
if (-e $db.nseqs) set nseqs = "-minseqs `cat $db.nseqs`"

#
# run MAST 
#
echo "<ul><li>/opt/chipster/tools/meme_4.2.0/bin/mast $motifs $db $* $nseqs $bfile -text -nostatus -stdout > mast.txt</li></ul><hr>" >> index.html
#
eval "/opt/chipster/tools/meme_4.2.0/bin/mast $motifs $db $* $nseqs $bfile -text -nostatus -stdout > mast.txt"
# Create html output
if ($status == 0) /opt/chipster/tools/meme_4.2.0/bin/mast2html < mast.txt > mast.html

# Get finish time for log
set t2 = `date -u '+%d/%m/%y %H:%M:%S'`

# Log the job
touch $logfile
set host = `hostname`
set submit = `cat submit_time_file`
set email = `cat address_file`
echo "$host $jobid submit: $submit start: $t1 end: $t2 $* $email" >> $logfile

#
# finish the index file
#
# Results section
if (-s mast.html || -s mast.txt) then
  echo "<h2>Results</h2><blockquote><ul>" >> index.html
  if (-s mast.html) echo "<li><a href='mast.html'>MAST output as HTML</a></li>" >> index.html
  if (-s mast.txt) echo "<li><a href='mast.txt'>MAST output as plain text</a></li>" >> index.html
  if (-s motifs) echo "<li><a href='motifs'>input motifs</a></li>" >> index.html
  #if (-s uploaded_db) echo "<li><a href='uploaded_db'>uploaded database</a></li>" >> index.html
  echo "</ul></blockquote><hr>" >> index.html
endif

# Messages section
if (-s stdout.txt || -s stderr.txt) then
  echo "<h2>Messages</h2><blockquote><ul>" >> index.html
  if (-s stdout.txt) echo "<li><a href='stdout.txt'>Processing Messages</a></li>" >> index.html
  if (-s stderr.txt) echo "<li><a href='stderr.txt'>Error Messages</a></li>" >> index.html
  echo "</ul></blockquote><hr>" >> index.html
endif

# End section
echo "</body></html>" >> index.html
